#!/usr/bin/env python

#TODO: Has to be converted to event based boot system
#TODO: none of them (systemd/upstart) are officially supported by Debian at the time of writing

from syncloud.boot.boot import Boot
from syncloud.boot.system import System

if __name__ == '__main__':

    boot = Boot(System(), ['/dev/sda1', '/dev/sdb1'], '/data', 10, 'www-data')
    boot.mount_data()
    boot.sync_time()
